@@ -7,6 +7,7 @@ import win32com.shell.shell as shell
 
 TASK_PARAMS_FILE_NAME = 'nowyou_task_params.txt'
 PLUGIN_PATH_NAME = 'nowyou_autorun'
+PLUGIN_RESOURCES_PATH = 'resources'
 
 
 def export_avatar(
@@ -17,11 +18,11 @@ def export_avatar(
 ) -> str:
 
     # copy plugin script to VStitcher folder
+    plugin_path = os.path.join(vstitcher_data_path, 'Plugins')
+    plugin_folder = os.path.join(plugin_path, PLUGIN_PATH_NAME)
     with zipfile.ZipFile(resource_path('\\vstitcher_plugins\\avatar_export.zip'), 'r') as zip_ref:
-        plugin_path = os.path.join(vstitcher_data_path, 'Plugins')
 
         # clean previous version of plugin
-        plugin_folder = os.path.join(plugin_path, PLUGIN_PATH_NAME)
         if os.path.exists(plugin_folder) and os.path.isdir(plugin_folder):
             shutil.rmtree(plugin_folder)
 
@@ -35,7 +36,7 @@ def export_avatar(
     data = json.dumps(params)
 
     # save JSON params to file
-    with open(os.path.join(work_path, TASK_PARAMS_FILE_NAME), 'w') as outfile:
+    with open(os.path.join(plugin_folder, PLUGIN_RESOURCES_PATH, TASK_PARAMS_FILE_NAME), 'w') as outfile:
         json.dump(data, outfile)
 
     # launch VStitcher
